'use strict';

var viewportWidth = {
    higherThan: function (breakpoint) { return "@media (min-width: " + (breakpoint + 1) + "px)"; },
    lowerThan: function (breakpoint) { return "@media (max-width: " + breakpoint + "px)"; },
    between: function (breakpointMin, breakpointMax) {
        return "@media (max-width: " + breakpointMax + "px) and (min-width: " + (breakpointMin + 1) + "px)";
    }
};
var viewportHeight = {
    higherThan: function (breakpoint) { return "@media (min-height: " + (breakpoint + 1) + ")"; },
    lowerThan: function (breakpoint) { return "@media (max-height: " + breakpoint + "px)"; },
    between: function (breakpointMin, breakpointMax) {
        return "@media (max-height: " + breakpointMax + ")px and (min-height: " + (breakpointMin + 1) + "px)";
    }
};

var formatDate = function (date) {
    var year = date.getFullYear();
    var month = (date.getMonth() + 1).toString().padStart(2, '0');
    var day = date.getDate().toString().padStart(2, '0');
    return year + "/" + month + "/" + day;
};
var formatSalary = function (salaryFrom, salaryTo) {
    return "$ " + Math.round(salaryFrom / 1000) + "k - $ " + Math.round(salaryTo / 1000) + "k";
};
var formatDateToTimeAgo = function (time) {
    // expected string 'YYYY/MM/DD'
    var timeSeconds = (typeof time === 'string' ? new Date(time) : time).getTime();
    var timeFormats = [
        [60, 'seconds', 1],
        [120, '1 minute ago', '1 minute from now'],
        [3600, 'minutes', 60],
        [7200, '1 hour ago', '1 hour from now'],
        [86400, 'hours', 3600],
        [172800, 'Yesterday', 'Tomorrow'],
        [604800, 'days', 86400],
        [1209600, 'Last week', 'Next week'],
        [2419200, 'weeks', 604800],
        [4838400, 'Last month', 'Next month'],
        [29030400, 'months', 2419200],
        [58060800, 'Last year', 'Next year'],
        [2903040000, 'years', 29030400] // 60*60*24*7*4*12*100, 60*60*24*7*4*12
    ];
    var seconds = (new Date().getTime() - timeSeconds) / 1000;
    var token = 'ago';
    var list_choice = 1;
    if (seconds == 0) {
        return 'Just now';
    }
    if (seconds < 0) {
        seconds = Math.abs(seconds);
        token = 'from now';
        list_choice = 2;
    }
    for (var _i = 0, timeFormats_1 = timeFormats; _i < timeFormats_1.length; _i++) {
        var format = timeFormats_1[_i];
        if (seconds < format[0]) {
            if (typeof format[2] == 'string')
                return format[list_choice];
            else
                return Math.floor(seconds / format[2]) + " " + format[1] + " " + token;
        }
    }
    return time;
};

var capitalize = function (str) { return str.charAt(0).toUpperCase() + str.slice(1); };

var isTimeEquals = function (time1, time2, compareSeconds) {
    if (compareSeconds === void 0) { compareSeconds = false; }
    if (!time1 || !time2)
        return false;
    return (time1.getHours() === time2.getHours() &&
        time1.getMinutes() === time2.getMinutes() &&
        (!compareSeconds || time1.getSeconds() === time2.getSeconds()));
};

exports.capitalize = capitalize;
exports.formatDate = formatDate;
exports.formatDateToTimeAgo = formatDateToTimeAgo;
exports.formatSalary = formatSalary;
exports.isTimeEquals = isTimeEquals;
exports.viewportHeight = viewportHeight;
exports.viewportWidth = viewportWidth;
